@@ -6,6 +6,7 @@ import contextlib
 import logging
 import multiprocessing
 import os
+import pdb
 import subprocess
 import sys
 import tempfile
@@ -166,25 +167,25 @@ def walkup(path="right here"):
             path = parent_path
 
 
-def figure_out_pager():
+def figure_out_pager(environ):
 
     """
     Return None or a pager program.
     """
 
-    if 'PAGER' in os.environ:
-        return os.environ['PAGER']
+    if 'PAGER' in environ:
+        return environ['PAGER'].split(' ')
 
     # This ain't gonna work on windows...
     dev_null = open('/dev/null', 'w')
 
     # Use `which less` to look for a path to less.
     if subprocess.Popen(['which', 'less'], stdout=dev_null).wait() == 0:
-        return 'less'
+        return ['less']
 
     # Use `which more` to look for a path to more.
     if subprocess.Popen(['which', 'more'], stdout=dev_null).wait() == 0:
-        return 'more'
+        return ['more']
 
 
 def send_through_pager(s, pager=None):
@@ -196,7 +197,7 @@ def send_through_pager(s, pager=None):
     """
 
     if pager:
-        p = subprocess.Popen([pager], stdin=subprocess.PIPE)
+        p = subprocess.Popen(listmofize(pager), stdin=subprocess.PIPE)
         p.communicate(s)
 
     else:
@@ -331,4 +332,12 @@ def time_ago(date):
         else:
             return "just now"
 
+def into_debugger(f):
 
+    def g(*args, **kwargs):
+        try:
+            return f(*args, **kwargs)
+        except:
+            pdb.post_mortem()
+
+    return g
